@@ -5,7 +5,8 @@ from typing import Any
 
 class PyNotiTask(object):
     __task_id: str = ""
-    __delay: int = 0
+    __preprocessor: callable = None
+    __delay: float = 0
     __fn: callable = None
     __args: Any = None
     __kwargs: dict[str, Any] = None
@@ -14,22 +15,24 @@ class PyNotiTask(object):
     def __init__(
         self,
         task_id: str,
-        delay: int,
+        delay: float,
         fn: callable,
+        preprocessor: callable,
         *args: Any,
         **kwargs: Any,
     ):
         self.__task_id = task_id
+        self.__preprocessor = preprocessor
         self.__delay = delay
         self.__fn = fn
         self.__args = args
         self.__kwargs = kwargs
 
     @property
-    def delay(self) -> int:
+    def delay(self) -> float:
         return self.__delay
 
-    def set_delay(self, delay: int):
+    def set_delay(self, delay: float):
         self.__delay = delay
 
     @property
@@ -55,6 +58,10 @@ class PyNotiTask(object):
             return
         logging.debug(f"Task[{self.__task_id}] execute.")
         try:
-            self.__fn(*self.__args, **self.__kwargs)
+            handled = False
+            if self.__preprocessor is not None:
+                handled = self.__preprocessor(self.__fn, *self.__args, **self.__kwargs)
+            if not handled:
+                self.__fn(*self.__args, **self.__kwargs)
         except Exception as e:
             logging.error(e)
